@@ -142,6 +142,9 @@ void MainContext::setupActions(QQmlApplicationEngine *engine) // singleton funct
         Q_ASSERT(action);
         QQmlComponent component(engine, QUrl(QStringLiteral("qrc:/ui/Action.qml")));
         QObject *object = component.create();
+        if (!object) {
+            qWarning() << "Failed to load component:" << component.errorString();
+        }
         Q_ASSERT(object);
         object->setProperty("iconName", action->icon().name());
         object->setProperty("text", action->text());
@@ -201,14 +204,6 @@ bool MainContext::slotScanUrl(const QUrl &url)
     return false;
 }
 
-void MainContext::urlAboutToChange() const
-{
-    // called when part's URL is about to change internally
-    // the part will then create the Map and emit completed()
-
-    m_histories->push(url());
-}
-
 bool MainContext::openUrl(const QUrl &u)
 {
     // TODO everyone hates dialogs, instead render the text in big fonts on the Map
